@@ -42,7 +42,7 @@ class OssFileCache():
         @param del_local: 缓存后是否删除本地文件
         """
         if not isinstance(file_path, str) and not isinstance(file_path, dict) and not isinstance(file_path, list) \
-                and file_path is not None and not re.match("http", file_path) and not os.path.exists(file_path) :
+                and file_path is not None and not re.match("http", file_path) and not os.path.exists(file_path):
             raise FileNotFoundError(file_path)
 
         local_cache_path = '/tmp/%s.%s' % (self.random_str(30), self.random_str(30))
@@ -85,18 +85,23 @@ class OssFileCache():
                 os.remove(local_file)
             return False
 
-    def delete(self, key):
+    def delete(self, key=None):
         """
         删除OSS缓存文件
         @param key:
         """
-        cache_path = "%s/%s/%s" % (self.cache_path_root, self.namespace, key)
-
-        try:
-            self.bucket.delete_object(cache_path)
+        if key is None:
+            items = self.list_cache_objects()
+            for item in items:
+                self.bucket.delete_object(item.key)
             return True
-        except oss2.exceptions.NoSuchKey:
-            return False
+        else:
+            cache_path = "%s/%s/%s" % (self.cache_path_root, self.namespace, key)
+            try:
+                self.bucket.delete_object(cache_path)
+                return True
+            except Exception as e:
+                return False
 
     def exist(self, key):
         """
@@ -117,7 +122,7 @@ class OssFileCache():
         marker = ''
         begin = False
         while (marker != '') or (not begin):
-            list_objects = self.bucket.list_objects(prefix=prefix_path, max_keys=100, marker=marker)
+            list_objects = self.bucket.list_objects(prefix=prefix_path, max_keys=300, marker=marker)
             marker = list_objects.next_marker
             begin = True
             for i in list_objects.object_list:
